// AUTO-GENERATED BY UpdateGenVersion.bat 424f5883ef7ad48e9f2157af850fee2453b31871
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "424f5883ef7ad48e9f2157af850fee2453b31871";
